# WARNING: This file is managed by bifrost.
clouds:
{% if (enable_keystone | default(false) | bool) %}
{% for cloud in clouds | default({}) | dictsort %}
  {{ cloud.0 }}:
    region_name: {{ cloud.1.config_region_name }}
    auth:
      username: {{ cloud.1.config_username }}
      password: {{ cloud.1.config_password }}
      project_name: {{ cloud.1.config_project_name }}
      auth_url: {{ cloud.1.config_auth_url }}
      project_domain_id: "{{ cloud.1.config_project_domain_id | default('default') }}"
      user_domain_id: "{{ cloud.1.config_user_domain_id | default('default') }}"
    identity_api_version: "3"
{% endfor %}
{% else %}
  bifrost:
    auth_type: "none"
    endpoint: {{ ironic_api_url }}
{% endif %}
