# {{ ansible_managed }}
# For additional details on configuring ironic, you may wish to reference
# the sample configuration file which can be located at
# http://git.openstack.org/cgit/openstack/ironic/tree/etc/ironic/ironic.conf.sample


[DEFAULT]
debug = {{ testing | bool }}
# NOTE(TheJulia): Until Bifrost supports neutron or some other network
# configuration besides a flat network where bifrost orchustrates the
# control instead of ironic, noop is the only available network driver.
enabled_network_interfaces = noop
default_deploy_interface = {{ default_deploy_interface }}
{% if enable_inspector | bool == true %}
enabled_inspect_interfaces = no-inspect,inspector
default_inspect_interface = inspector
{% endif %}
enabled_boot_interfaces = {{ enabled_boot_interfaces }}
enabled_management_interfaces = {{ enabled_management_interfaces }}
enabled_power_interfaces = {{ enabled_power_interfaces }}

enabled_hardware_types = {{ enabled_hardware_types }}
enabled_drivers = {{ enabled_drivers }}

rabbit_userid = ironic
rabbit_password = {{ ironic_db_password }}

{% if enable_keystone is defined and enable_keystone | bool == true %}
auth_strategy = keystone
{% else %}
auth_strategy = noauth
{% endif %}

{% if ironic_log_dir is defined %}
log_dir = {{ ironic_log_dir }}
{% endif %}

[pxe]
pxe_append_params = systemd.journald.forward_to_console=yes {{ extra_kernel_options | default('') }}
pxe_config_template = $pybasedir/drivers/modules/ipxe_config.template
tftp_server = {{ hostvars[inventory_hostname]['ansible_' + ans_network_interface]['ipv4']['address'] }}
tftp_root = /tftpboot
pxe_bootfile_name = undionly.kpxe
ipxe_enabled = true
ipxe_boot_script = /etc/ironic/boot.ipxe
tftp_master_path = /var/lib/ironic/master_images

[deploy]
http_url = http://{{ hostvars[inventory_hostname]['ansible_' + ans_network_interface]['ipv4']['address'] }}:{{ file_url_port }}/
http_root = {{ http_boot_folder }}

[conductor]
api_url = http://{{ hostvars[inventory_hostname]['ansible_' + ans_network_interface]['ipv4']['address'] }}:6385/
clean_nodes = {{ cleaning | lower }}
automated_clean = {{ cleaning | lower }}

[database]
connection = mysql+pymysql://{{ ironic.database.username }}:{{ ironic.database.password }}@{{ ironic.database.host }}/{{ ironic.database.name }}?charset=utf8

[dhcp]
dhcp_provider = none

{% if testing | bool == true %}
[ssh]
libvirt_uri = qemu:///system
{% endif %}

{% if enable_cors | bool == true %}
[cors]
allowed_origin = {{ cors_allowed_origin | default('allowed_origin=http://localhost:8000') }}
allow_credentials = {{ enable_cors_credential_support | default('true') }}
{% endif %}

[ilo]
use_web_server_for_images = true

{% if enable_inspector | bool == true %}
[inspector]
enabled = true
{% endif %}
{% if enable_keystone is defined and enable_keystone | bool == true %}
auth_type = password
auth_url = {{ ironic.service_catalog.auth_url }}
username = {{ ironic.service_catalog.username }}
password = {{ ironic.service_catalog.password }}
user_domain_id = default
project_name = {{ ironic.service_catalog.project_name }}
project_domain_id = default
{% else %}
auth_type=none
endpoint_override=http://127.0.0.1:5050
{% endif %}

{% if enable_keystone is defined and enable_keystone | bool == true %}
[keystone]
region_name = {{ keystone.bootstrap.region_name | default('RegionOne')}}
[keystone_authtoken]
auth_plugin = password
auth_url = {{ ironic.service_catalog.auth_url }}
username = {{ ironic.service_catalog.username }}
password = {{ ironic.service_catalog.password }}
user_domain_id = default
project_name = {{ ironic.service_catalog.project_name }}
project_domain_id = default

[service_catalog]
auth_url = {{ ironic.service_catalog.auth_url }}
auth_type = password
tenant_name = {{ ironic.service_catalog.project_name }}
username = {{ ironic.service_catalog.username }}
password = {{ ironic.service_catalog.password }}
{% endif %}
