{
    "availability_zone": "",
{% if write_interfaces_file | bool == true %}
    "files": [
        {
            "content_path": "/content/0000",
            "path": "/etc/network/interfaces"
        }
    ],
{% else %}
    "files": [],
{% endif %}
    "hostname": {{ name|to_json }},
    "name": {{ name|to_json }},
    "meta": {},
    "public_keys": {
        "mykey": {{ ssh_public_key|to_json }}
    },
    "uuid": "{{ uuid }}"
}
